@@ -1,5 +1,3 @@
-/* $Id: server.c,v 1.20 2005/12/12 09:38:09 jamesh Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -53,6 +51,9 @@ GLIBTOP_SUID_PROC_SEGMENT +
 GLIBTOP_SUID_PROC_ARGS +
 GLIBTOP_SUID_PROC_MAP +
 GLIBTOP_SUID_NETLOAD +
+GLIBTOP_SUID_NETLIST +
+GLIBTOP_SUID_PROC_WD +
+GLIBTOP_SUID_PROC_AFFINITY +
 GLIBTOP_SUID_PPP;
 
 #include <fcntl.h>
